Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(441)

Unified Diff: runtime/tests/vm/dart/isolate_mirror_remote_test.dart

Issue 10700149: Some small changes to make the vm dart:mirrors somewhat closer to the (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/tests/vm/dart/isolate_mirror_local_test.dart ('k') | runtime/vm/bootstrap_natives.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/tests/vm/dart/isolate_mirror_remote_test.dart
===================================================================
--- runtime/tests/vm/dart/isolate_mirror_remote_test.dart (revision 9527)
+++ runtime/tests/vm/dart/isolate_mirror_remote_test.dart (working copy)
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
//
// Dart test program for checking implemention of IsolateMirror when
// inspecting a remote isolate.
#library('isolate_mirror_local_test');
@@ -17,14 +17,14 @@
});
}
-void testIsolateMirror(IsolateMirror mirror) {
+void testMirrorSystem(MirrorSystem mirror) {
Expect.fail('Should not reach here. Remote isolates not implemented.');
}
void main() {
SendPort sp = spawnFunction(isolateMain);
try {
- isolateMirrorOf(sp).then(testIsolateMirror);
+ mirrorSystemOf(sp).then(testMirrorSystem);
Expect.fail('Should not reach here. Remote isolates not implemented.');
} catch (var exception) {
Expect.isTrue(exception is NotImplementedException);
@@ -2,7 +2,7 @@
// BSD-style license that can be found in the LICENSE file.
//
-// Dart test program for checking implemention of IsolateMirror when
+// Dart test program for checking implemention of MirrorSystem when
// inspecting a remote isolate.
#library('isolate_mirror_local_test');
« no previous file with comments | « runtime/tests/vm/dart/isolate_mirror_local_test.dart ('k') | runtime/vm/bootstrap_natives.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698